@@ -32,6 +32,10 @@ class Context(Config):
     def environment(self):
         return self.get('environment', {}, False)
 
+    @property
+    def notebook(self) -> bool:
+        return self.get('features.notebook', False, False)
+
     @property
     def dotenv(self) -> dict:
         return dotenv_values(self.file('.env'))
